@@ -322,7 +322,7 @@ static void sound_button_toggled (HildonCheckButton *button, gpointer data) {
 }
 
 static void guide_clicked(GtkWidget *b, gpointer data) {
-	system(_("dbus-send --print-reply --dest=com.nokia.osso_browser /com/nokia/osso_browser/service com.nokia.osso_browser.open_new_window string:file:///usr/share/100boxes/index.html"));
+	system(_("browser --url=file:///usr/share/100boxes/index.html &"));
 }
 
 void new_game(struct game_data *d) {
